@@ -3,9 +3,9 @@ use warnings FATAL => 'all';
 
 package Data::Scan;
 
-# ABSTRACT: Data::Scan - Stackfree arbitrary data scanner
+# ABSTRACT: Stackfree arbitrary data scanner
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 # AUTHORITY
 
@@ -22,54 +22,44 @@ has consumer => (
 
 
 my $_open;
-my $_read;
 my $_close;
+my $openaddr = \$_open;
+my $closeaddr = \$_close;
 
 
 sub process {
   my ($self) = shift;
 
-  my $consumer = $self->consumer;
-  my $openaddr = \$_open;
-  my $closeaddr = \$_close;
-
-  my $previous;
-  my $inner;
-  my $reftype;
-
+  my ($consumer, $previous, $inner) = $self->consumer;
   #
   # Start
   #
-  $consumer->start;
+  $consumer->start();                                                                    # start()
+  #
+  # Loop
+  #
   while (@_) {
     #
     # First our private thingies
     #
-    while (ref $_[$[]) {
-      if    ($openaddr  == refaddr $_[$[]) { $consumer->sopen ((splice @_, $[, 2)[-1]) } # sopen(item)
-      elsif ($closeaddr == refaddr $_[$[]) { $consumer->sclose((splice @_, $[, 2)[-1]) } # sclose(item)
+    while (@_ && ref $_[$[]) {
+      if    ($openaddr  == refaddr $_[$[]) { $consumer->sopen ((splice @_, $[, 2)[-1]) } # sopen($item)
+      elsif ($closeaddr == refaddr $_[$[]) { $consumer->sclose((splice @_, $[, 2)[-1]) } # sclose($item)
       else                                 { last }
     }
-    if (@_) {
-      #
-      # Consumer's sread() returns eventual inner content
-      #
-      if (defined($inner = $consumer->sread($previous = shift))) {
-        my $reftype = reftype($inner) // '';
-        unshift(@_,
-                $openaddr, $previous,
-                @{$inner},
-                $closeaddr, $previous
-               ) if ($reftype eq 'ARRAY')
-      }
-    } else {
-      last
-    }
+    #
+    # Consumer's sread() returns eventual inner content
+    #
+    unshift(@_,
+            $openaddr, $previous,
+            @{$inner},
+            $closeaddr, $previous
+           ) if (@_ && defined($inner = $consumer->sread($previous = shift)) && (reftype($inner) // '') eq 'ARRAY')
   }
   #
   # End - return value of consumer's end() is what we return
   #
-  $consumer->end;
+  return $consumer->end()                                                                # end()
 }
 
 1;
@@ -82,11 +72,11 @@ __END__
 
 =head1 NAME
 
-Data::Scan - Data::Scan - Stackfree arbitrary data scanner
+Data::Scan - Stackfree arbitrary data scanner
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -110,33 +100,33 @@ Data::Scan is a stackfree scanner of arbitrary data. It has no other intelligenc
 
 Instantiate a new Data::Scan object. Takes as parameter a required consumer, that is consuming the Data::Scan::Role::Consumer role.
 
-=head2 $self->process(@arguments)
+=head2 $self->process(Any @arguments)
 
-Scan over all items in @arguments and will call the consumer with these five methods:
+Scan over all items in @arguments and will call the consumer with these five methods/signatures:
 
 =over
 
-=item $consumer->start
+=item $consumer->start()
 
 Indicates to the consumer that scanning is starting. Return value is ignored.
 
-=item $consumer->sopen($item)
+=item $consumer->sopen(Any $item)
 
 Indicates to the consumer that an unfold of $item is starting. Return value is ignored.
 
-=item $consumer->sread($item)
+=item $consumer->sread(Any $item)
 
 Indicates to the consumer that he should take over $item. If the consumer is deciding to unfold it (typically when this is an ARRAY or a HASH reference), it should return an array reference containing the unfolded content. Anything but an an array reference means it has not been unfolded.
 
 The consumer has full control on the workflow and can decide to unfold or not whatever is meaningful to him.
 
-=item $consumer->sclose($item)
+=item $consumer->sclose(Any $item)
 
 Indicates to the consumer that an unfold of $item is ending. Return value is ignored.
 
-=item $consumer->end
+=item $consumer->end()
 
-Indicates to the consumer that scanning is ending.
+Indicates to the consumer that scanning is ending. Return value of consumer->end() will be the return value of $self->process(@arguments).
 
 =back
 
@@ -163,6 +153,12 @@ L<https://github.com/jddurand/data-scan>
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mohammad S Anwar
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 by Jean-Damien Durand.
