@@ -5,7 +5,7 @@ package Data::Scan::Printer;
 
 # ABSTRACT: Data::Scan::Printer - Example of a printer consumer for Data::Scan
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 # AUTHORITY
 
@@ -26,6 +26,7 @@ sub dspp {
   print $consumer->output
 }
 
+
 1;
 
 __END__
@@ -40,7 +41,16 @@ Data::Scan::Printer - Data::Scan::Printer - Example of a printer consumer for Da
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 SYNOPSIS
+
+    use strict;
+    use warnings FATAL => 'all';
+    use Data::Scan::Printer;
+
+    my $this = bless([ 'var1', 'var2', {'a' => 'b', 'c' => 'd'}, \undef, \\undef, [] ], 'TEST');
+    dspp($this);
 
 =head1 DESCRIPTION
 
@@ -52,6 +62,10 @@ Data::Scan::Printer is polluting user's namespace with a dspp() method, showing
 
 Print to STDOUT a dumped vision of the arguments.
 
+=head1 SEE ALSO
+
+L<Data::Printer>
+
 =head1 AUTHOR
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
